hepfile package
=================

Submodules
------------

hepfile\.read module
---------------------

.. automodule:: hepfile.read
    :members:
    :undoc-members:
    :show-inheritance:

hepfile\.write module
-------------------------

.. automodule:: hepfile.write
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hepfile
    :members:
    :undoc-members:
    :show-inheritance:
